@@ -1,7 +1,7 @@
 #!/bin/sh
 
 if [ ! -z "$COVERAGE" ]; then
-    COVERAGE="--cov-report= --cov-append --cov-branch --cov paramsurvey -v -v"
+    COVERAGE="--cov-report=xml --cov-append --cov-branch --cov paramsurvey -v -v"
 fi
 
 if [ ! -z "$ONLY_BUILTINS" ]; then
